==> openGion6.6.0.1_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE53S.sql <==
/****************************************************************************/
/* GE53 ( 振分条件ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2016/10/27 10:56:48                                            */
/****************************************************************************/

CREATE TABLE GE53 (
   SYSTEM_ID        VARCHAR (  10 )                         NOT NULL            /*  10 ｼｽﾃﾑID       */
 , JOKEN            VARCHAR (  20 )                         NOT NULL            /*  20 振分条件     */
 , FGRUN            VARCHAR (   1 )                         NOT NULL            /*  30 実行方法     */
 , PRTID            VARCHAR (  20 )                                             /*  40 ﾌﾟﾘﾝﾀID      */
 , LANG             VARCHAR (   2 )                                             /*  50 言語         */
 , PRGDIR           VARCHAR ( 100 )                         NOT NULL            /*  60 実行PGDIR    */
 , PRGFILE          VARCHAR (  50 )                         NOT NULL            /*  70 実行PGﾌｧｲﾙ名 */
 , COMMENTS         VARCHAR ( 500 )                                             /*  80 ｺﾒﾝﾄ         */
 , DMN_GRP          VARCHAR (  20 )     DEFAULT 'DG0000'    NOT NULL            /*  90 ﾃﾞｰﾓﾝｸﾞﾙｰﾌﾟ  */
 , DMN_TIME         INTEGER             DEFAULT 5           NOT NULL            /* 100 ﾃﾞｰﾓﾝ間隔    */
 , RELEASE_NOTES    VARCHAR ( 120 )                                             /* 110 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR (  20 )                                             /* 120 設変番号     */
 , OUT_DIR          VARCHAR ( 100 )                                             /* 130 出力ﾌｧｲﾙDIR  */
 , OUT_FILE         VARCHAR (  50 )                                             /* 140 出力ﾌｧｲﾙ名   */
 , JKN_GRP          VARCHAR (  20 )                                             /* 150 条件ｸﾞﾙｰﾌﾟ   */
 , FGJ              VARCHAR (   1 )     DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR (  14 )                                             /* 820 登録日時     */
 , PGSET            VARCHAR (  10 )                                             /* 830 作成PG       */
 , PGPSET           VARCHAR (  10 )                                             /* 840 作成親PG     */
 , USRSET           VARCHAR (  10 )                                             /* 850 作成社員     */
 , DYUPD            VARCHAR (  14 )                                             /* 860 更新日時     */
 , PGUPD            VARCHAR (  10 )                                             /* 870 更新PG       */
 , PGPUPD           VARCHAR (  10 )                                             /* 880 更新親PG     */
 , USRUPD           VARCHAR (  10 )                                             /* 890 更新者       */
);

==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE53S.sql <==
/****************************************************************************/
/* GE53 ( 振分条件ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:23                                            */
/****************************************************************************/

CREATE TABLE GE53 (
   SYSTEM_ID        VARCHAR (  10 )                         NOT NULL            /*  10 ｼｽﾃﾑID       */
 , JOKEN            VARCHAR (  20 )                         NOT NULL            /*  20 振分条件     */
 , FGRUN            VARCHAR (   1 )                         NOT NULL            /*  30 実行方法     */
 , PRTID            VARCHAR (  20 )                                             /*  40 ﾌﾟﾘﾝﾀID      */
 , LANG             VARCHAR (   2 )                                             /*  50 言語         */
 , PRGDIR           VARCHAR ( 100 )                         NOT NULL            /*  60 実行PGDIR    */
 , PRGFILE          VARCHAR (  50 )                         NOT NULL            /*  70 実行PGﾌｧｲﾙ名 */
 , COMMENTS         VARCHAR ( 500 )                                             /*  80 ｺﾒﾝﾄ         */
 , DMN_GRP          VARCHAR (  20 )     DEFAULT 'DG0000'    NOT NULL            /*  90 ﾃﾞｰﾓﾝｸﾞﾙｰﾌﾟ  */
 , DMN_TIME         INTEGER             DEFAULT 5           NOT NULL            /* 100 ﾃﾞｰﾓﾝ間隔    */
 , RELEASE_NOTES    VARCHAR ( 120 )                                             /* 110 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR (  20 )                                             /* 120 設変番号     */
 , OUT_DIR          VARCHAR ( 100 )                                             /* 130 出力ﾌｧｲﾙDIR  */
 , OUT_FILE         VARCHAR (  50 )                                             /* 140 出力ﾌｧｲﾙ名   */
 , JKN_GRP          VARCHAR (  20 )                                             /* 150 条件ｸﾞﾙｰﾌﾟ   */
 , FGJ              VARCHAR (   1 )     DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR (  14 )                                             /* 820 登録日時     */
 , PGSET            VARCHAR (  10 )                                             /* 830 作成PG       */
 , PGPSET           VARCHAR (  10 )                                             /* 840 作成親PG     */
 , USRSET           VARCHAR (  10 )                                             /* 850 作成者       */
 , DYUPD            VARCHAR (  14 )                                             /* 860 更新日時     */
 , PGUPD            VARCHAR (  10 )                                             /* 870 更新PG       */
 , PGPUPD           VARCHAR (  10 )                                             /* 880 更新親PG     */
 , USRUPD           VARCHAR (  10 )                                             /* 890 更新者       */
);
